@@ -16,13 +16,13 @@
 package org.gradle.api.internal.changedetection.state;
 
 import org.gradle.api.file.FileCollection;
-import org.gradle.messaging.serialize.SerializerRegistry;
+import org.gradle.internal.serialize.SerializerRegistry;
 
 public interface FileCollectionSnapshotter {
     /**
      * Registers the serializer(s) that can be used to serialize the {@link FileCollectionSnapshot} implementations produced by this snapshotter.
      */
-    void registerSerializers(SerializerRegistry<FileCollectionSnapshot> registry);
+    void registerSerializers(SerializerRegistry registry);
 
     /**
      * Creates an empty snapshot, which changes can be later merged into.
@@ -35,7 +35,8 @@ public interface FileCollectionSnapshotter {
      * Creates a snapshot of the contents of the given collection
      *
      * @param files The files to snapshot
+     * @param allowReuse When true, can use cached snapshot trees
      * @return The snapshot.
      */
-    FileCollectionSnapshot snapshot(FileCollection files);
+    FileCollectionSnapshot snapshot(FileCollection files, boolean allowReuse);
 }
