@@ -25,12 +25,15 @@ import org.gradle.internal.BiAction;
 import org.gradle.internal.Factory;
 import org.gradle.internal.reflect.Instantiator;
 import org.gradle.model.collection.internal.BridgedCollections;
-import org.gradle.model.collection.internal.ModelMapModelProjection;
+import org.gradle.model.internal.core.ChildNodeInitializerStrategyAccessors;
+import org.gradle.model.internal.core.ModelMapModelProjection;
 import org.gradle.model.internal.core.*;
 import org.gradle.model.internal.core.rule.describe.SimpleModelRuleDescriptor;
 import org.gradle.model.internal.registry.ModelRegistry;
 import org.gradle.model.internal.type.ModelType;
 
+import static org.gradle.model.internal.core.NodePredicate.allLinks;
+
 public class DefaultTaskContainerFactory implements Factory<TaskContainerInternal> {
     private final ModelRegistry modelRegistry;
     private final Instantiator instantiator;
@@ -49,7 +52,7 @@ public class DefaultTaskContainerFactory implements Factory<TaskContainerInterna
     public TaskContainerInternal create() {
         ModelReference<DefaultTaskContainer> containerReference = ModelReference.of(TaskContainerInternal.MODEL_PATH, DefaultTaskContainer.class);
 
-        ModelCreators.Builder creatorBuilder = BridgedCollections.creator(
+        ModelRegistrations.Builder registrationBuilder = BridgedCollections.registration(
             containerReference,
             new Transformer<DefaultTaskContainer, MutableModelNode>() {
                 @Override
@@ -62,28 +65,25 @@ public class DefaultTaskContainerFactory implements Factory<TaskContainerInterna
             new Namer()
         );
 
-        modelRegistry.createOrReplace(
-            creatorBuilder
-                .withProjection(ModelMapModelProjection.unmanaged(Task.class, NodeBackedModelMap.createUsingParentNode(new Transformer<NamedEntityInstantiator<Task>, MutableModelNode>() {
+        modelRegistry.register(
+            registrationBuilder
+                .withProjection(ModelMapModelProjection.unmanaged(Task.class, ChildNodeInitializerStrategyAccessors.of(NodeBackedModelMap.createUsingParentNode(new Transformer<NamedEntityInstantiator<Task>, MutableModelNode>() {
                     @Override
                     public NamedEntityInstantiator<Task> transform(MutableModelNode modelNode) {
                         return modelNode.getPrivateData(ModelType.of(DefaultTaskContainer.class)).getEntityInstantiator();
                     }
-                })))
+                }))))
                 .withProjection(UnmanagedModelProjection.of(TaskContainer.class))
                 .build()
         );
 
         ModelNode modelNode = modelRegistry.atStateOrLater(TaskContainerInternal.MODEL_PATH, ModelNode.State.Created);
-        if (modelNode == null) {
-            throw new IllegalStateException("Couldn't get task container from model registry");
-        }
 
         // TODO LD use something more stable than a cast here
         MutableModelNode mutableModelNode = (MutableModelNode) modelNode;
 
         // Add tasks created through rules to the actual task container
-        mutableModelNode.applyToAllLinks(ModelActionRole.Mutate, DirectNodeNoInputsModelAction.of(ModelReference.of(Task.class), new SimpleModelRuleDescriptor("copyToTaskContainer"), new BiAction<MutableModelNode, Task>() {
+        mutableModelNode.applyTo(allLinks(), ModelActionRole.Initialize, DirectNodeNoInputsModelAction.of(ModelReference.of(Task.class), new SimpleModelRuleDescriptor("copyToTaskContainer"), new BiAction<MutableModelNode, Task>() {
             @Override
             public void execute(MutableModelNode modelNode, Task task) {
                 TaskContainerInternal taskContainer = modelNode.getParent().getPrivateData(TaskContainerInternal.MODEL_TYPE);
