@@ -136,6 +136,19 @@ public class JavaReflectionUtil {
      * @throws NoSuchPropertyException when the given property does not exist.
      */
     public static PropertyMutator writeableProperty(Class<?> target, String property) throws NoSuchPropertyException {
+        PropertyMutator mutator = writeablePropertyIfExists(target, property);
+        if (mutator != null) {
+            return mutator;
+        }
+        throw new NoSuchPropertyException(String.format("Could not find setter method for property '%s' on class %s.", property, target.getSimpleName()));
+    }
+
+    /**
+     * Locates the property with the given name as a writable property. Searches only public properties.
+     *
+     * Returns null if no such property exists.
+     */
+    public static PropertyMutator writeablePropertyIfExists(Class<?> target, String property) throws NoSuchPropertyException {
         String setterName = toMethodName("set", property);
         for (final Method method : target.getMethods()) {
             if (!method.getName().equals(setterName)) {
@@ -149,7 +162,22 @@ public class JavaReflectionUtil {
             }
             return new MethodBackedPropertyMutator(property, method);
         }
-        throw new NoSuchPropertyException(String.format("Could not find setter method for property '%s' on class %s.", property, target.getSimpleName()));
+        return null;
+    }
+
+    /**
+     * Locates the field with the given name as a writable property. Searches only public properties.
+     *
+     * @throws NoSuchPropertyException when the given property does not exist.
+     */
+    public static PropertyMutator writeableField(Class<?> target, String fieldName) throws NoSuchPropertyException {
+        Field field;
+        try {
+            field = target.getField(fieldName);
+            return new FieldBackedPropertyMutator(fieldName, field);
+        } catch (java.lang.NoSuchFieldException e) {
+            throw new NoSuchPropertyException(String.format("Could not find writeable field '%s' on class %s.", fieldName, target.getSimpleName()));
+        }
     }
 
     private static String toMethodName(String prefix, String propertyName) {
@@ -438,6 +466,37 @@ public class JavaReflectionUtil {
         }
     }
 
+    private static class FieldBackedPropertyMutator implements PropertyMutator {
+        private final String name;
+        private final Field field;
+
+        public FieldBackedPropertyMutator(String name, Field field) {
+            this.name = name;
+            this.field = field;
+        }
+
+        @Override
+        public String toString() {
+            return String.format("field %s.%s", field.getDeclaringClass().getSimpleName(), name);
+        }
+
+        public String getName() {
+            return name;
+        }
+
+        public Class<?> getType() {
+            return field.getType();
+        }
+
+        public void setValue(Object target, Object value) {
+            try {
+                field.set(target, value);
+            } catch (IllegalAccessException e) {
+                throw UncheckedException.throwAsUncheckedException(e);
+            }
+        }
+    }
+
     private static class InstantiatingFactory<T> implements Factory<T> {
         private final Instantiator instantiator;
         private final Class<? extends T> type;
