@@ -16,6 +16,7 @@
 
 package org.gradle.internal.service.scopes;
 
+import com.google.common.annotations.VisibleForTesting;
 import org.gradle.StartParameter;
 import org.gradle.api.Action;
 import org.gradle.api.Project;
@@ -24,12 +25,14 @@ import org.gradle.api.internal.artifacts.DefaultModule;
 import org.gradle.api.internal.artifacts.DependencyManagementServices;
 import org.gradle.api.internal.artifacts.ModuleInternal;
 import org.gradle.api.internal.artifacts.configurations.DependencyMetaDataProvider;
+import org.gradle.api.internal.changedetection.state.CachingFileSnapshotter;
 import org.gradle.api.internal.classpath.ModuleRegistry;
 import org.gradle.api.internal.classpath.PluginModuleRegistry;
 import org.gradle.api.internal.component.ComponentTypeRegistry;
 import org.gradle.api.internal.component.DefaultComponentTypeRegistry;
 import org.gradle.api.internal.file.FileLookup;
 import org.gradle.api.internal.file.FileResolver;
+import org.gradle.api.internal.file.collections.DirectoryFileTreeFactory;
 import org.gradle.api.internal.initialization.DefaultScriptHandlerFactory;
 import org.gradle.api.internal.initialization.ScriptHandlerFactory;
 import org.gradle.api.internal.initialization.loadercache.ClassLoaderCache;
@@ -37,15 +40,13 @@ import org.gradle.api.internal.plugins.DefaultPluginRegistry;
 import org.gradle.api.internal.plugins.PluginInspector;
 import org.gradle.api.internal.plugins.PluginRegistry;
 import org.gradle.api.internal.project.*;
+import org.gradle.api.internal.project.antbuilder.DefaultIsolatedAntBuilder;
 import org.gradle.api.internal.project.taskfactory.AnnotationProcessingTaskFactory;
 import org.gradle.api.internal.project.taskfactory.DependencyAutoWireTaskFactory;
 import org.gradle.api.internal.project.taskfactory.ITaskFactory;
 import org.gradle.api.internal.project.taskfactory.TaskFactory;
 import org.gradle.cache.CacheRepository;
 import org.gradle.cache.CacheValidator;
-import org.gradle.cache.internal.CacheFactory;
-import org.gradle.cache.internal.DefaultCacheRepository;
-import org.gradle.cache.internal.DefaultCacheScopeMapping;
 import org.gradle.configuration.*;
 import org.gradle.configuration.project.*;
 import org.gradle.execution.ProjectConfigurer;
@@ -57,13 +58,16 @@ import org.gradle.groovy.scripts.internal.*;
 import org.gradle.initialization.*;
 import org.gradle.initialization.buildsrc.BuildSourceBuilder;
 import org.gradle.initialization.layout.BuildLayoutFactory;
-import org.gradle.internal.Factory;
 import org.gradle.internal.TimeProvider;
 import org.gradle.internal.TrueTimeProvider;
+import org.gradle.internal.authentication.AuthenticationSchemeRegistry;
+import org.gradle.internal.authentication.DefaultAuthenticationSchemeRegistry;
 import org.gradle.internal.classloader.ClassLoaderFactory;
+import org.gradle.internal.classpath.ClassPath;
+import org.gradle.internal.concurrent.CompositeStoppable;
 import org.gradle.internal.concurrent.ExecutorFactory;
+import org.gradle.internal.concurrent.Stoppable;
 import org.gradle.internal.event.ListenerManager;
-import org.gradle.internal.id.LongIdGenerator;
 import org.gradle.internal.operations.logging.BuildOperationLoggerFactory;
 import org.gradle.internal.operations.logging.DefaultBuildOperationLoggerFactory;
 import org.gradle.internal.progress.BuildOperationExecutor;
@@ -80,27 +84,39 @@ import org.gradle.logging.ProgressLoggerFactory;
 import org.gradle.logging.ShowStacktrace;
 import org.gradle.messaging.actor.ActorFactory;
 import org.gradle.messaging.actor.internal.DefaultActorFactory;
-import org.gradle.messaging.remote.MessagingServer;
 import org.gradle.model.internal.inspect.ModelRuleSourceDetector;
 import org.gradle.plugin.use.internal.PluginRequestApplicator;
-import org.gradle.process.internal.DefaultWorkerProcessFactory;
-import org.gradle.process.internal.WorkerProcessBuilder;
-import org.gradle.process.internal.child.WorkerProcessClassPathProvider;
 import org.gradle.profile.ProfileEventAdapter;
 import org.gradle.profile.ProfileListener;
-import org.gradle.util.GradleVersion;
 
 /**
  * Contains the singleton services for a single build invocation.
  */
 public class BuildScopeServices extends DefaultServiceRegistry {
 
-    public BuildScopeServices(final ServiceRegistry parent, final StartParameter startParameter) {
-        super(parent);
+    private final BuildSessionScopeServices sessionServices;
+    private final boolean singleUseSession;
+
+    public static BuildScopeServices forSession(BuildSessionScopeServices sessionServices) {
+        return new BuildScopeServices(sessionServices, false);
+    }
+
+    public static BuildScopeServices singleSession(ServiceRegistry parent, StartParameter startParameter) {
+        return new BuildScopeServices(parent, startParameter);
+    }
+
+    protected BuildScopeServices(ServiceRegistry parent, StartParameter startParameter) {
+        this(new BuildSessionScopeServices(parent, startParameter, ClassPath.EMPTY), true);
+    }
+
+    @VisibleForTesting
+    BuildScopeServices(final BuildSessionScopeServices sessionServices, boolean singleUseSession) {
+        super(sessionServices);
+        this.sessionServices = sessionServices;
+        this.singleUseSession = singleUseSession;
         register(new Action<ServiceRegistration>() {
             public void execute(ServiceRegistration registration) {
-                add(StartParameter.class, startParameter);
-                for (PluginServiceRegistry pluginServiceRegistry : parent.getAll(PluginServiceRegistry.class)) {
+                for (PluginServiceRegistry pluginServiceRegistry : sessionServices.getAll(PluginServiceRegistry.class)) {
                     pluginServiceRegistry.registerBuildServices(registration);
                 }
             }
@@ -129,17 +145,12 @@ public class BuildScopeServices extends DefaultServiceRegistry {
 
     protected ClassPathRegistry createClassPathRegistry() {
         return new DefaultClassPathRegistry(
-                new DefaultClassPathProvider(get(ModuleRegistry.class)),
-                new DependencyClassPathProvider(get(ModuleRegistry.class),
-                        get(PluginModuleRegistry.class)),
-                get(WorkerProcessClassPathProvider.class)
+            new DefaultClassPathProvider(get(ModuleRegistry.class)),
+            new DependencyClassPathProvider(get(ModuleRegistry.class),
+                get(PluginModuleRegistry.class))
         );
     }
 
-    protected WorkerProcessClassPathProvider createWorkerProcessClassPathProvider(CacheRepository cacheRepository, ModuleRegistry moduleRegistry) {
-        return new WorkerProcessClassPathProvider(cacheRepository, moduleRegistry);
-    }
-
     protected IsolatedAntBuilder createIsolatedAntBuilder() {
         return new DefaultIsolatedAntBuilder(get(ClassPathRegistry.class), get(ClassLoaderFactory.class));
     }
@@ -154,79 +165,70 @@ public class BuildScopeServices extends DefaultServiceRegistry {
 
     protected BuildLoader createBuildLoader() {
         return new ProjectPropertySettingBuildLoader(
-                get(IGradlePropertiesLoader.class),
-                new InstantiatingBuildLoader(get(IProjectFactory.class)));
-    }
-
-    protected CacheRepository createCacheRepository() {
-        CacheFactory factory = get(CacheFactory.class);
-        StartParameter startParameter = get(StartParameter.class);
-        DefaultCacheScopeMapping scopeMapping = new DefaultCacheScopeMapping(startParameter.getGradleUserHomeDir(), startParameter.getProjectCacheDir(), GradleVersion.current());
-        return new DefaultCacheRepository(
-                scopeMapping,
-                factory);
+            get(IGradlePropertiesLoader.class),
+            new InstantiatingBuildLoader(get(IProjectFactory.class)));
     }
 
     protected ProjectEvaluator createProjectEvaluator() {
         ConfigureActionsProjectEvaluator withActionsEvaluator = new ConfigureActionsProjectEvaluator(
-                new PluginsProjectConfigureActions(get(ClassLoaderRegistry.class).getPluginsClassLoader()),
-                new BuildScriptProcessor(get(ScriptPluginFactory.class)),
-                new DelayedConfigurationActions()
+            new PluginsProjectConfigureActions(get(ClassLoaderRegistry.class).getPluginsClassLoader()),
+            new BuildScriptProcessor(get(ScriptPluginFactory.class)),
+            new DelayedConfigurationActions()
         );
         return new LifecycleProjectEvaluator(withActionsEvaluator);
     }
 
     protected ITaskFactory createITaskFactory() {
         return new DependencyAutoWireTaskFactory(
-                new AnnotationProcessingTaskFactory(
-                        new TaskFactory(
-                                get(ClassGenerator.class))
-                )
+            new AnnotationProcessingTaskFactory(
+                new TaskFactory(
+                    get(ClassGenerator.class))
+            )
         );
     }
 
-    protected ScriptCompilerFactory createScriptCompileFactory(ListenerManager listenerManager, FileCacheBackedScriptClassCompiler scriptCompiler, ClassLoaderCache classLoaderCache) {
+    protected ScriptCompilerFactory createScriptCompileFactory(ListenerManager listenerManager, FileCacheBackedScriptClassCompiler scriptCompiler,
+                                                               CrossBuildInMemoryCachingScriptClassCache cache) {
         ScriptExecutionListener scriptExecutionListener = listenerManager.getBroadcaster(ScriptExecutionListener.class);
         return new DefaultScriptCompilerFactory(
-                new CachingScriptClassCompiler(
-                        new ShortCircuitEmptyScriptCompiler(
-                                scriptCompiler,
-                                classLoaderCache
-                        )
-                ),
-                new DefaultScriptRunnerFactory(
-                        scriptExecutionListener,
-                        DirectInstantiator.INSTANCE
-                )
+            new BuildScopeInMemoryCachingScriptClassCompiler(cache, scriptCompiler),
+            new DefaultScriptRunnerFactory(
+                scriptExecutionListener,
+                DirectInstantiator.INSTANCE
+            )
         );
     }
 
     protected FileCacheBackedScriptClassCompiler createFileCacheBackedScriptClassCompiler(
-            CacheRepository cacheRepository, final StartParameter startParameter,
-            ProgressLoggerFactory progressLoggerFactory, ClassLoaderCache classLoaderCache, ImportsReader importsReader) {
+        CacheRepository cacheRepository, final StartParameter startParameter,
+        ProgressLoggerFactory progressLoggerFactory, ClassLoaderCache classLoaderCache, ImportsReader importsReader,
+        CachingFileSnapshotter snapshotter, ClassLoaderRegistry registry) {
         CacheValidator scriptCacheInvalidator = new CacheValidator() {
             public boolean isValid() {
                 return !startParameter.isRecompileScripts();
             }
         };
         return new FileCacheBackedScriptClassCompiler(
-                cacheRepository,
-                scriptCacheInvalidator,
-                new DefaultScriptCompilationHandler(classLoaderCache, importsReader),
-                progressLoggerFactory
-        );
+            cacheRepository,
+            scriptCacheInvalidator,
+            new DefaultScriptCompilationHandler(classLoaderCache, importsReader),
+            progressLoggerFactory,
+            snapshotter,
+            classLoaderCache,
+            registry);
     }
 
     protected ScriptPluginFactory createScriptObjectConfigurerFactory() {
         return new DefaultScriptPluginFactory(
-                get(ScriptCompilerFactory.class),
-                getFactory(LoggingManagerInternal.class),
-                get(Instantiator.class),
-                get(ScriptHandlerFactory.class),
-                get(PluginRequestApplicator.class),
-                get(FileLookup.class),
-                get(DocumentationRegistry.class),
-                get(ModelRuleSourceDetector.class)
+            get(ScriptCompilerFactory.class),
+            getFactory(LoggingManagerInternal.class),
+            get(Instantiator.class),
+            get(ScriptHandlerFactory.class),
+            get(PluginRequestApplicator.class),
+            get(FileLookup.class),
+            get(DirectoryFileTreeFactory.class),
+            get(DocumentationRegistry.class),
+            get(ModelRuleSourceDetector.class)
         );
     }
 
@@ -234,45 +236,45 @@ public class BuildScopeServices extends DefaultServiceRegistry {
                                                   ClassLoaderScopeRegistry classLoaderScopeRegistry, CacheRepository cacheRepository,
                                                   BuildLoader buildLoader, BuildOperationExecutor buildOperationExecutor) {
         return new NotifyingSettingsLoader(
-                new SettingsHandler(
-                        new DefaultSettingsFinder(
-                                new BuildLayoutFactory()),
-                        settingsProcessor,
-                        new BuildSourceBuilder(
-                                gradleLauncherFactory,
-                                classLoaderScopeRegistry.getCoreAndPluginsScope(),
-                                cacheRepository,
-                                buildOperationExecutor)
-                ),
-                buildLoader);
+            new SettingsHandler(
+                new DefaultSettingsFinder(
+                    new BuildLayoutFactory()),
+                settingsProcessor,
+                new BuildSourceBuilder(
+                    gradleLauncherFactory,
+                    classLoaderScopeRegistry.getCoreAndPluginsScope(),
+                    cacheRepository,
+                    buildOperationExecutor)
+            ),
+            buildLoader);
     }
 
     protected InitScriptHandler createInitScriptHandler(ScriptPluginFactory scriptPluginFactory, ScriptHandlerFactory scriptHandlerFactory, BuildOperationExecutor buildOperationExecutor) {
         return new InitScriptHandler(
-                new DefaultInitScriptProcessor(
-                        scriptPluginFactory,
-                        scriptHandlerFactory
-                ),
-                buildOperationExecutor
+            new DefaultInitScriptProcessor(
+                scriptPluginFactory,
+                scriptHandlerFactory
+            ),
+            buildOperationExecutor
         );
     }
 
     protected SettingsProcessor createSettingsProcessor(ScriptPluginFactory scriptPluginFactory, ScriptHandlerFactory scriptHandlerFactory, Instantiator instantiator,
                                                         ServiceRegistryFactory serviceRegistryFactory, IGradlePropertiesLoader propertiesLoader, BuildOperationExecutor buildOperationExecutor) {
         return new NotifyingSettingsProcessor(
-                new PropertiesLoadingSettingsProcessor(
-                        new ScriptEvaluatingSettingsProcessor(
-                                scriptPluginFactory,
-                                scriptHandlerFactory,
-                                new SettingsFactory(
-                                        instantiator,
-                                        serviceRegistryFactory
-                                ),
-                                propertiesLoader
-                        ),
-                        propertiesLoader
+            new PropertiesLoadingSettingsProcessor(
+                new ScriptEvaluatingSettingsProcessor(
+                    scriptPluginFactory,
+                    scriptHandlerFactory,
+                    new SettingsFactory(
+                        instantiator,
+                        serviceRegistryFactory
+                    ),
+                    propertiesLoader
                 ),
-                buildOperationExecutor);
+                propertiesLoader
+            ),
+            buildOperationExecutor);
     }
 
     protected ExceptionAnalyser createExceptionAnalyser(ListenerManager listenerManager, LoggingConfiguration loggingConfiguration) {
@@ -285,23 +287,12 @@ public class BuildScopeServices extends DefaultServiceRegistry {
 
     protected ScriptHandlerFactory createScriptHandlerFactory() {
         return new DefaultScriptHandlerFactory(
-                get(DependencyManagementServices.class),
-                get(FileResolver.class),
-                get(DependencyMetaDataProvider.class)
+            get(DependencyManagementServices.class),
+            get(FileResolver.class),
+            get(DependencyMetaDataProvider.class)
         );
     }
 
-    protected Factory<WorkerProcessBuilder> createWorkerProcessFactory(StartParameter startParameter, MessagingServer messagingServer, ClassPathRegistry classPathRegistry,
-                                                                       FileResolver fileResolver) {
-        return new DefaultWorkerProcessFactory(
-                startParameter.getLogLevel(),
-                messagingServer,
-                classPathRegistry,
-                fileResolver,
-                new LongIdGenerator(),
-                startParameter.getGradleUserHomeDir());
-    }
-
     protected ProjectConfigurer createProjectConfigurer(BuildCancellationToken cancellationToken) {
         return new TaskPathProjectEvaluator(cancellationToken);
     }
@@ -356,4 +347,23 @@ public class BuildScopeServices extends DefaultServiceRegistry {
         return new DefaultBuildOperationLoggerFactory();
     }
 
+    AuthenticationSchemeRegistry createAuthenticationSchemeRegistry() {
+        return new DefaultAuthenticationSchemeRegistry();
+    }
+
+    @Override
+    public void close() {
+        if (singleUseSession) {
+            // This song and dance is to let CompositeStoppable deal with making sure everything
+            // is closed when something errors while stopping
+            CompositeStoppable.stoppable(new Stoppable() {
+                @Override
+                public void stop() {
+                    BuildScopeServices.super.close();
+                }
+            }, sessionServices).stop();
+        } else {
+            super.close();
+        }
+    }
 }
