@@ -2182,6 +2182,11 @@ public class ClassReader {
      * @return a non null Label, which must be equal to labels[offset].
      */
     protected Label readLabel(int offset, Label[] labels) {
+        // SPRING PATCH: leniently handle offset mismatch
+        if (offset >= labels.length) {
+            return new Label();
+        }
+        // END OF PATCH
         if (labels[offset] == null) {
             labels[offset] = new Label();
         }
