@@ -23,6 +23,8 @@ import java.io.IOException;
 import java.util.List;
 import java.util.Properties;
 
+import joptsimple.OptionSet;
+
 import org.springframework.boot.cli.command.options.CompilerOptionHandler;
 import org.springframework.boot.cli.command.options.OptionSetGroovyCompilerConfiguration;
 import org.springframework.boot.cli.compiler.GroovyCompilerConfiguration;
@@ -32,8 +34,6 @@ import org.springframework.boot.cli.util.Log;
 import org.springframework.util.FileCopyUtils;
 import org.springframework.util.SystemPropertyUtils;
 
-import joptsimple.OptionSet;
-
 /**
  * Shared logic for the {@link InstallCommand} and {@link UninstallCommand}.
  *
@@ -46,13 +46,13 @@ class Installer {
 
 	private final Properties installCounts;
 
-	public Installer(OptionSet options, CompilerOptionHandler compilerOptionHandler)
+	Installer(OptionSet options, CompilerOptionHandler compilerOptionHandler)
 			throws IOException {
 		this(new GroovyGrabDependencyResolver(
 				createCompilerConfiguration(options, compilerOptionHandler)));
 	}
 
-	public Installer(DependencyResolver resolver) throws IOException {
+	Installer(DependencyResolver resolver) throws IOException {
 		this.dependencyResolver = resolver;
 		this.installCounts = loadInstallCounts();
 	}
