@@ -26,7 +26,10 @@ import java.util.Map;
 import java.util.ServiceLoader;
 import java.util.Set;
 
+import jline.console.ConsoleReader;
+import jline.console.completer.CandidateListCompletionHandler;
 import org.fusesource.jansi.AnsiRenderer.Code;
+
 import org.springframework.boot.cli.command.Command;
 import org.springframework.boot.cli.command.CommandFactory;
 import org.springframework.boot.cli.command.CommandRunner;
@@ -35,9 +38,6 @@ import org.springframework.boot.cli.command.core.VersionCommand;
 import org.springframework.boot.loader.tools.SignalUtils;
 import org.springframework.util.StringUtils;
 
-import jline.console.ConsoleReader;
-import jline.console.completer.CandidateListCompletionHandler;
-
 /**
  * A shell for Spring Boot. Drops the user into an event loop (REPL) where command line
  * completion and history are available without relying on OS shell features.
@@ -66,9 +66,9 @@ public class Shell {
 
 	/**
 	 * Create a new {@link Shell} instance.
-	 * @throws IOException
+	 * @throws IOException in case of I/O errors
 	 */
-	public Shell() throws IOException {
+	Shell() throws IOException {
 		attachSignalHandler();
 		this.consoleReader = new ConsoleReader();
 		this.commandRunner = createCommandRunner();
@@ -175,7 +175,7 @@ public class Shell {
 	}
 
 	/**
-	 * Final handle an interrup signal (CTRL-C)
+	 * Final handle an interrupt signal (CTRL-C).
 	 */
 	protected void handleSigInt() {
 		if (this.commandRunner.handleSigInt()) {
@@ -195,7 +195,7 @@ public class Shell {
 
 		private final Map<String, String> aliases = new HashMap<String, String>();
 
-		public ShellCommandRunner() {
+		ShellCommandRunner() {
 			super(null);
 		}
 
