@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2014 the original author or authors.
+ * Copyright 2012-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,15 +22,15 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 
+import groovy.lang.Grab;
 import org.codehaus.groovy.ast.AnnotationNode;
 import org.codehaus.groovy.ast.expr.ConstantExpression;
 import org.codehaus.groovy.ast.expr.Expression;
 import org.codehaus.groovy.transform.ASTTransformation;
+
 import org.springframework.boot.cli.compiler.grape.DependencyResolutionContext;
 import org.springframework.core.annotation.Order;
 
-import groovy.lang.Grab;
-
 /**
  * {@link ASTTransformation} to resolve {@link Grab} artifact coordinates.
  *
@@ -41,7 +41,10 @@ import groovy.lang.Grab;
 public class ResolveDependencyCoordinatesTransformation
 		extends AnnotatedNodeASTTransformation {
 
-	public static final int ORDER = GrabMetadataTransformation.ORDER + 300;
+	/**
+	 * The order of the transformation.
+	 */
+	public static final int ORDER = DependencyManagementBomTransformation.ORDER + 300;
 
 	private static final Set<String> GRAB_ANNOTATION_NAMES = Collections
 			.unmodifiableSet(new HashSet<String>(
@@ -51,7 +54,7 @@ public class ResolveDependencyCoordinatesTransformation
 
 	public ResolveDependencyCoordinatesTransformation(
 			DependencyResolutionContext resolutionContext) {
-		super(GRAB_ANNOTATION_NAMES);
+		super(GRAB_ANNOTATION_NAMES, false);
 		this.resolutionContext = resolutionContext;
 	}
 
