@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2013 the original author or authors.
+ * Copyright 2012-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ package org.springframework.boot.cli.compiler.autoconfigure;
 import org.codehaus.groovy.ast.ClassNode;
 import org.codehaus.groovy.control.CompilationFailedException;
 import org.codehaus.groovy.control.customizers.ImportCustomizer;
+
 import org.springframework.boot.cli.compiler.AstUtils;
 import org.springframework.boot.cli.compiler.CompilerAutoConfiguration;
 import org.springframework.boot.cli.compiler.DependencyCustomizer;
@@ -44,14 +45,10 @@ public class JmsCompilerAutoConfiguration extends CompilerAutoConfiguration {
 	}
 
 	@Override
-	@SuppressWarnings("deprecation")
 	public void applyImports(ImportCustomizer imports) throws CompilationFailedException {
 		imports.addStarImports("javax.jms", "org.springframework.jms.annotation",
 				"org.springframework.jms.config", "org.springframework.jms.core",
 				"org.springframework.jms.listener",
-				"org.springframework.jms.listener.adapter")
-				.addImports(org.springframework.boot.groovy.EnableJmsMessaging.class
-						.getCanonicalName());
+				"org.springframework.jms.listener.adapter");
 	}
-
 }
