@@ -58,6 +58,8 @@ import org.springframework.util.StringUtils;
  */
 public class Log4J2LoggingSystem extends Slf4JLoggingSystem {
 
+	private static final String FILE_PROTOCOL = "file";
+
 	private static final Map<LogLevel, Level> LEVELS;
 
 	static {
@@ -128,13 +130,13 @@ public class Log4J2LoggingSystem extends Slf4JLoggingSystem {
 	@Override
 	public void beforeInitialize() {
 		super.beforeInitialize();
-		getRootLoggerConfig().addFilter(FILTER);
+		getLoggerContext().getConfiguration().addFilter(FILTER);
 	}
 
 	@Override
 	public void initialize(LoggingInitializationContext initializationContext,
 			String configLocation, LogFile logFile) {
-		getRootLoggerConfig().removeFilter(FILTER);
+		getLoggerContext().getConfiguration().removeFilter(FILTER);
 		super.initialize(initializationContext, configLocation, logFile);
 	}
 
@@ -172,7 +174,7 @@ public class Log4J2LoggingSystem extends Slf4JLoggingSystem {
 
 	private ConfigurationSource getConfigurationSource(URL url) throws IOException {
 		InputStream stream = url.openStream();
-		if (ResourceUtils.isFileURL(url)) {
+		if (FILE_PROTOCOL.equals(url.getProtocol())) {
 			return new ConfigurationSource(stream, ResourceUtils.getFile(url));
 		}
 		return new ConfigurationSource(stream, url);
@@ -202,10 +204,6 @@ public class Log4J2LoggingSystem extends Slf4JLoggingSystem {
 		return new ShutdownHandler();
 	}
 
-	private LoggerConfig getRootLoggerConfig() {
-		return getLoggerContext().getConfiguration().getLoggerConfig("");
-	}
-
 	private LoggerConfig getLoggerConfig(String name) {
 		name = (StringUtils.hasText(name) ? name : LogManager.ROOT_LOGGER_NAME);
 		return getLoggerContext().getConfiguration().getLoggers().get(name);
