@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2015 the original author or authors.
+ * Copyright 2002-2016 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,13 +22,12 @@ import java.util.List;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import org.springframework.beans.BeanUtils;
 import org.springframework.core.annotation.AnnotatedElementUtils;
 import org.springframework.core.annotation.AnnotationUtils;
 import org.springframework.util.ClassUtils;
 import org.springframework.util.MultiValueMap;
 
-import static org.springframework.beans.BeanUtils.*;
-
 /**
  * {@code BootstrapUtils} is a collection of utility methods to assist with
  * bootstrapping the <em>Spring TestContext Framework</em>.
@@ -41,47 +40,41 @@ import static org.springframework.beans.BeanUtils.*;
  */
 abstract class BootstrapUtils {
 
-	private static final String DEFAULT_BOOTSTRAP_CONTEXT_CLASS_NAME = "org.springframework.test.context.support.DefaultBootstrapContext";
+	private static final String DEFAULT_BOOTSTRAP_CONTEXT_CLASS_NAME =
+			"org.springframework.test.context.support.DefaultBootstrapContext";
 
-	private static final String DEFAULT_CACHE_AWARE_CONTEXT_LOADER_DELEGATE_CLASS_NAME = "org.springframework.test.context.cache.DefaultCacheAwareContextLoaderDelegate";
+	private static final String DEFAULT_CACHE_AWARE_CONTEXT_LOADER_DELEGATE_CLASS_NAME =
+			"org.springframework.test.context.cache.DefaultCacheAwareContextLoaderDelegate";
 
-	private static final String DEFAULT_TEST_CONTEXT_BOOTSTRAPPER_CLASS_NAME = "org.springframework.test.context.support.DefaultTestContextBootstrapper";
+	private static final String DEFAULT_TEST_CONTEXT_BOOTSTRAPPER_CLASS_NAME =
+			"org.springframework.test.context.support.DefaultTestContextBootstrapper";
 
 	private static final Log logger = LogFactory.getLog(BootstrapUtils.class);
 
 
-	private BootstrapUtils() {
-		/* no-op */
-	}
-
 	/**
 	 * Create the {@code BootstrapContext} for the specified {@linkplain Class test class}.
-	 *
 	 * <p>Uses reflection to create a {@link org.springframework.test.context.support.DefaultBootstrapContext}
 	 * that uses a {@link org.springframework.test.context.cache.DefaultCacheAwareContextLoaderDelegate}.
-	 *
 	 * @param testClass the test class for which the bootstrap context should be created
 	 * @return a new {@code BootstrapContext}; never {@code null}
 	 */
 	@SuppressWarnings("unchecked")
 	static BootstrapContext createBootstrapContext(Class<?> testClass) {
 		CacheAwareContextLoaderDelegate cacheAwareContextLoaderDelegate = createCacheAwareContextLoaderDelegate();
-
 		Class<? extends BootstrapContext> clazz = null;
 		try {
-			clazz = (Class<? extends BootstrapContext>) ClassUtils.forName(DEFAULT_BOOTSTRAP_CONTEXT_CLASS_NAME,
-				BootstrapUtils.class.getClassLoader());
-
-			Constructor<? extends BootstrapContext> constructor = clazz.getConstructor(Class.class,
-				CacheAwareContextLoaderDelegate.class);
-
+			clazz = (Class<? extends BootstrapContext>) ClassUtils.forName(
+					DEFAULT_BOOTSTRAP_CONTEXT_CLASS_NAME, BootstrapUtils.class.getClassLoader());
+			Constructor<? extends BootstrapContext> constructor = clazz.getConstructor(
+					Class.class, CacheAwareContextLoaderDelegate.class);
 			if (logger.isDebugEnabled()) {
 				logger.debug(String.format("Instantiating BootstrapContext using constructor [%s]", constructor));
 			}
-			return instantiateClass(constructor, testClass, cacheAwareContextLoaderDelegate);
+			return BeanUtils.instantiateClass(constructor, testClass, cacheAwareContextLoaderDelegate);
 		}
-		catch (Throwable t) {
-			throw new IllegalStateException("Could not load BootstrapContext [" + clazz + "]", t);
+		catch (Throwable ex) {
+			throw new IllegalStateException("Could not load BootstrapContext [" + clazz + "]", ex);
 		}
 	}
 
@@ -96,10 +89,10 @@ abstract class BootstrapUtils {
 				logger.debug(String.format("Instantiating CacheAwareContextLoaderDelegate from class [%s]",
 					clazz.getName()));
 			}
-			return instantiateClass(clazz, CacheAwareContextLoaderDelegate.class);
+			return BeanUtils.instantiateClass(clazz, CacheAwareContextLoaderDelegate.class);
 		}
-		catch (Throwable t) {
-			throw new IllegalStateException("Could not load CacheAwareContextLoaderDelegate [" + clazz + "]", t);
+		catch (Throwable ex) {
+			throw new IllegalStateException("Could not load CacheAwareContextLoaderDelegate [" + clazz + "]", ex);
 		}
 	}
 
@@ -107,13 +100,11 @@ abstract class BootstrapUtils {
 	 * Resolve the {@link TestContextBootstrapper} type for the test class in the
 	 * supplied {@link BootstrapContext}, instantiate it, and provide it a reference
 	 * to the {@link BootstrapContext}.
-	 *
 	 * <p>If the {@link BootstrapWith @BootstrapWith} annotation is present on
 	 * the test class, either directly or as a meta-annotation, then its
 	 * {@link BootstrapWith#value value} will be used as the bootstrapper type.
 	 * Otherwise, the {@link org.springframework.test.context.support.DefaultTestContextBootstrapper
 	 * DefaultTestContextBootstrapper} will be used.
-	 *
 	 * @param bootstrapContext the bootstrap context to use
 	 * @return a fully configured {@code TestContextBootstrapper}
 	 */
@@ -123,17 +114,14 @@ abstract class BootstrapUtils {
 
 		Class<? extends TestContextBootstrapper> clazz = null;
 		try {
-
 			MultiValueMap<String, Object> attributesMultiMap = AnnotatedElementUtils.getAllAnnotationAttributes(
 				testClass, BootstrapWith.class.getName());
 			List<Object> values = (attributesMultiMap == null ? null : attributesMultiMap.get(AnnotationUtils.VALUE));
 
 			if (values != null) {
 				if (values.size() != 1) {
-					String msg = String.format(
-						"Configuration error: found multiple declarations of @BootstrapWith on test class [%s] with values %s",
-						testClass.getName(), values);
-					throw new IllegalStateException(msg);
+					throw new IllegalStateException(String.format("Configuration error: found multiple declarations of " +
+							"@BootstrapWith on test class [%s] with values %s", testClass.getName(), values));
 				}
 				clazz = (Class<? extends TestContextBootstrapper>) values.get(0);
 			}
@@ -144,22 +132,21 @@ abstract class BootstrapUtils {
 
 			if (logger.isDebugEnabled()) {
 				logger.debug(String.format("Instantiating TestContextBootstrapper for test class [%s] from class [%s]",
-					testClass.getName(), clazz.getName()));
+						testClass.getName(), clazz.getName()));
 			}
 
-			TestContextBootstrapper testContextBootstrapper = instantiateClass(clazz, TestContextBootstrapper.class);
+			TestContextBootstrapper testContextBootstrapper =
+					BeanUtils.instantiateClass(clazz, TestContextBootstrapper.class);
 			testContextBootstrapper.setBootstrapContext(bootstrapContext);
-
 			return testContextBootstrapper;
 		}
-		catch (Throwable t) {
-			if (t instanceof IllegalStateException) {
-				throw (IllegalStateException) t;
+		catch (Throwable ex) {
+			if (ex instanceof IllegalStateException) {
+				throw (IllegalStateException) ex;
 			}
-
-			throw new IllegalStateException("Could not load TestContextBootstrapper [" + clazz
-					+ "]. Specify @BootstrapWith's 'value' attribute "
-					+ "or make the default bootstrapper class available.", t);
+			throw new IllegalStateException("Could not load TestContextBootstrapper [" + clazz +
+					"]. Specify @BootstrapWith's 'value' attribute or make the default bootstrapper class available.",
+					ex);
 		}
 	}
 
