@@ -52,6 +52,11 @@ import java.util.regex.Pattern;
  * {@code org/springframework/testing/servlet/bla.jsp} and {@code org/servlet/bla.jsp}</li>
  * </ul>
  *
+ * <p><strong>Note:</strong> a pattern and a path must both be absolute or must
+ * both be relative in order for the two to match. Therefore it is recommended
+ * that users of this implementation to sanitize patterns in order to prefix
+ * them with "/" as it makes sense in the context in which they're used.
+ *
  * @author Alef Arendsen
  * @author Juergen Hoeller
  * @author Rob Harrop
@@ -74,6 +79,8 @@ public class AntPathMatcher implements PathMatcher {
 
 	private PathSeparatorPatternCache pathSeparatorPatternCache;
 
+	private boolean caseSensitive = true;
+
 	private boolean trimTokens = true;
 
 	private volatile Boolean cachePatterns;
@@ -112,6 +119,15 @@ public class AntPathMatcher implements PathMatcher {
 		this.pathSeparatorPatternCache = new PathSeparatorPatternCache(this.pathSeparator);
 	}
 
+	/**
+	 * Specify whether to perform pattern matching in a case-sensitive fashion.
+	 * <p>Default is {@code true}. Switch this to {@code false} for case-insensitive matching.
+	 * @since 4.2
+	 */
+	public void setCaseSensitive(boolean caseSensitive) {
+		this.caseSensitive = caseSensitive;
+	}
+
 	/**
 	 * Specify whether to trim tokenized paths and patterns.
 	 * <p>Default is {@code true}.
@@ -359,7 +375,7 @@ public class AntPathMatcher implements PathMatcher {
 			matcher = this.stringMatcherCache.get(pattern);
 		}
 		if (matcher == null) {
-			matcher = new AntPathStringMatcher(pattern);
+			matcher = new AntPathStringMatcher(pattern, this.caseSensitive);
 			if (cachePatterns == null && this.stringMatcherCache.size() >= CACHE_TURNOFF_THRESHOLD) {
 				// Try to adapt to the runtime situation that we're encountering:
 				// There are obviously too many different patterns coming in here...
@@ -460,7 +476,7 @@ public class AntPathMatcher implements PathMatcher {
 			return pattern1;
 		}
 
-		boolean pattern1ContainsUriVar = pattern1.indexOf('{') != -1;
+		boolean pattern1ContainsUriVar = (pattern1.indexOf('{') != -1);
 		if (!pattern1.equals(pattern2) && !pattern1ContainsUriVar && match(pattern1, pattern2)) {
 			// /* + /hotel -> /hotel ; "/*.*" + "/*.html" -> /*.html
 			// However /user + /user -> /usr/user ; /{foo} + /bar -> /{foo}/bar
@@ -485,12 +501,17 @@ public class AntPathMatcher implements PathMatcher {
 			return concat(pattern1, pattern2);
 		}
 
-		String extension1 = pattern1.substring(starDotPos1 + 1);
+		String ext1 = pattern1.substring(starDotPos1 + 1);
 		int dotPos2 = pattern2.indexOf('.');
-		String fileName2 = (dotPos2 == -1 ? pattern2 : pattern2.substring(0, dotPos2));
-		String extension2 = (dotPos2 == -1 ? "" : pattern2.substring(dotPos2));
-		String extension = extension1.startsWith("*") ? extension2 : extension1;
-		return fileName2 + extension;
+		String file2 = (dotPos2 == -1 ? pattern2 : pattern2.substring(0, dotPos2));
+		String ext2 = (dotPos2 == -1 ? "" : pattern2.substring(dotPos2));
+		boolean ext1All = (ext1.equals(".*") || ext1.equals(""));
+		boolean ext2All = (ext2.equals(".*") || ext2.equals(""));
+		if (!ext1All && !ext2All) {
+			throw new IllegalArgumentException("Cannot combine patterns: " + pattern1 + " vs " + pattern2);
+		}
+		String ext = (ext1All ? ext2 : ext1);
+		return file2 + ext;
 	}
 
 	private String concat(String path1, String path2) {
@@ -546,6 +567,10 @@ public class AntPathMatcher implements PathMatcher {
 		private final List<String> variableNames = new LinkedList<String>();
 
 		public AntPathStringMatcher(String pattern) {
+			this(pattern, true);
+		}
+
+		public AntPathStringMatcher(String pattern, boolean caseSensitive) {
 			StringBuilder patternBuilder = new StringBuilder();
 			Matcher matcher = GLOB_PATTERN.matcher(pattern);
 			int end = 0;
@@ -576,7 +601,8 @@ public class AntPathMatcher implements PathMatcher {
 				end = matcher.end();
 			}
 			patternBuilder.append(quote(pattern, end, pattern.length()));
-			this.pattern = Pattern.compile(patternBuilder.toString());
+			this.pattern = (caseSensitive ? Pattern.compile(patternBuilder.toString()) :
+					Pattern.compile(patternBuilder.toString(), Pattern.CASE_INSENSITIVE));
 		}
 
 		private String quote(String s, int start, int end) {
